@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: tclhfs.c,v 1.28 1998/02/19 19:34:51 rob Exp $
+ * $Id: tclhfs.c,v 1.10 1998/08/31 04:27:19 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -1052,6 +1052,21 @@ int vol_cmd(ClientData clientData, Tcl_Interp *interp,
 
 	  Tcl_SetResult(interp, result, TCL_DYNAMIC);
 	}
+      else if (strcmp(argv[1], "bless") == 0)
+	{
+	  hfsvolent volent;
+	  hfsdirent dirent;
+
+	  if (hfs_setcwd(vol, vref->cwd) == -1 ||
+	      hfs_vstat(vol, &volent) == -1 ||
+	      hfs_stat(vol, argv[2], &dirent) == -1)
+	    return error(interp, 0);
+
+	  volent.blessed = dirent.cnid;
+
+	  if (hfs_vsetattr(vol, &volent) == -1)
+	    return error(interp, 0);
+	}
       else
 	{
 	  Tcl_AppendResult(interp, "bad command \"", argv[1],
